/**
 * This file is part of SuperSimpleAI: An OpenTTD AI.
 *
 * Based on code from SimpleAI, written by Brumi.
 *
 * Author: Jaume Sabater
 *
 * It's free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *
 * You should have received a copy of the GNU General Public License
 * with it.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Define the MyAIIndustry class which extends the AIIndustry functions.
 */
class MyAIIndustry /* extends AIIndustry */
{
	/**
	 * Get the percentage of transported cargo from a given industry.
	 * @param ind The index of the industry.
	 * @param cargo The index of the cargo.
	 * @return The percentage transported, ranging from 0 to 100.
	 */
	static function GetLastMonthTransportedPercentage(ind, cargo);

	/**
	 * Get production percentage of cargo1 from cargo1 + cargo2.
	 * @param ind The index of the industry.
	 * @param cargo1 The index of the cargo1.
	 * @param cargo2 The index of the cargo2.
	 * @return The percentage of cargo1, ranging from 0 to 100.
	 */
	static function GetProductionPercentage(ind, cargo1, cargo2);
}

function MyAIIndustry::GetLastMonthTransportedPercentage(ind, cargo)
{
	local indprod = AIIndustry.GetLastMonthProduction(ind, cargo);
	if (indprod == 0 || indprod == null) return 99; // FindService do nothing.
	else return (100 * AIIndustry.GetLastMonthTransported(ind, cargo) / indprod);
}

function MyAIIndustry::GetProductionPercentage(ind, cargo1, cargo2)
{
	if (cargo2 == null) return 100;
	local prod1 = AIIndustry.GetLastMonthProduction(ind, cargo1);
	// Secondary indrustries can produce 0 in one month, we don't want divisions by 0.
	return (prod1 == 0) ? 50 : MyMath.Percent(prod1, prod1 + AIIndustry.GetLastMonthProduction(ind, cargo2));
}
